========
Aqueduct
========

Framework for performance-efficient prediction.

Key Benefits
============

- Increases the throughput of your machine learning-based service
- Uses shared memory for instantaneous transfer of large amounts of data between processes
- All optimizations in one library


Documentation
=============

- `Getting started <docs/getting_started.rst>`_
- `Batching <docs/batching.rst>`_
- `F.A.Q. <docs/faq.rst>`_
- Additional features
- - `Sentry support <docs/sentry.rst>`_

Examples
========

- `Aiohttp <examples/aiohttp/>`_
- `Flask <examples/flask/>`_

Contact Us
==========

Feel free to ask questions in Telegram: `t.me/avito-ml <https://t.me/avito_ml>`_
